3 ms·
That’s fair! It doesn’t go near the ballpark performance I was going after, though. It’s hard to assess to which extent the performance tweaking vs. rewriting
by espadrine 5y ago
That’s fair! It doesn’t go near the ballpark performance I was going after, though.
It’s hard to assess to which extent the performance tweaking vs. rewriting tradeoff scales up. For a larger project, the rewrite could take a month; but maybe, diminishing returns helping, the performance tweaking would plateau short of a month.
- kristofferc 5y agohttps://discourse.julialang.org/t/rust-julia-comparison-post/75403/16?u=kristoffer.carlsson https://discourse.julialang.org/t/rust-julia-comparison-post... seems to be about 2x faster than the (optimized) Rust version with some minor tweaks to the Julia code so perhaps that is more in your ballpark?
- espadrine 5y agoAbsolutely, that is what I was hoping for! So, vcat() instead of append!(). Darn. Faith in Julia restored. I’ll update the article.